@@ -55,7 +55,7 @@ bool cfgopt_load(cfgopt_t *cfg, char *fname){
 		char *tok_val;
 		tok_key = strtok(line, "=\"\t\n");
 		if(!tok_key) continue;
-		tok_val = strtok(NULL, "=\"\t\n");
+		tok_val = strtok(NULL, "\"\t\n");
 		if(!tok_val){
 			DEBUG("null value for key='%s'", tok_key);
 			continue;
