@@ -35,6 +35,7 @@ THE SOFTWARE.
 #include <pcap.h>
 
 #include "cfgopt.h"
+#include "uint.h"
 #include "util.h"
 
 /* macros */
@@ -75,6 +76,7 @@ typedef struct pcap_args {
 } pcap_args_t;
 
 const u_char *pcapnet_start_network_header(int datalink, const u_char *pkt, int *etype, size_t *len);
+const u_char *pcapnet_start_transport_header(int datalink, const u_char *pkt, size_t *len, u8 *proto);
 const u_char *pcapnet_start_app_layer(int datalink, const u_char *pkt, size_t *len);
 bool pcapnet_are_packets_available(pcap_args_t *);
 void pcapnet_break_loop(pcap_args_t *);
