@@ -23,7 +23,9 @@ extern int socket_bind6_reuse(int s, const char *ip, u16 port, u32 scope_id);
 extern int socket_connect4(int s, const char *ip, u16 port);
 extern int socket_connect6(int s, const char *ip, u16 port, u32 scope_id);
 extern int socket_listen(int s, unsigned backlog);
+extern int socket_recv4(int s, char *buf, int len, char ip[4], u16 *port);
 extern int socket_recv6(int s, char *buf, unsigned len, char *ip, u16 *port, u32 *scope_id);
+extern int socket_send4(int s, const char *buf, int len, const char ip[4], u16 port);
 extern int socket_send6(int s, const char *buf, unsigned len, const char *ip, u16 port, u32 scope_id);
 extern int socket_tcp(void);
 extern int socket_tcp6(void);
